#
# spec file for package riff
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           riff
Version:        3.4.0
Release:        1.1
Summary:        A diff filter highlighting which line parts have changed
License:        MIT
URL:            https://github.com/walles/riff
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo-packaging
Requires:       diff
ExclusiveArch:  %{rust_tier1_arches}

%description
Riff is a wrapper around diff that highlights which parts of lines have changed.

%prep
%autosetup -a1
install -D -m 644 %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
%{cargo_install}

%check
%{cargo_test}

%files
%{_bindir}/%{name}

%changelog
* Fri Jul  4 2025 Michael Vetter <mvetter@suse.com>
- Update to 3.4.0:
  * File names mentioned in the diff can now be clicked
* Mon Apr  7 2025 Michael Vetter <mvetter@suse.com>
- Update to 3.3.10:
  * Enable highlighting differences in ANSI styled text files.
* Mon Mar 24 2025 Michael Vetter <mvetter@suse.com>
- Update to 3.3.9:
  * Don't group Hiragana / Katakana into words
* Mon Jan 13 2025 Michael Vetter <mvetter@suse.com>
- Update to 3.3.8:
  * Accept arguments in PAGER variable
* Wed Nov 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 3.3.7:
  * Fix building with older Rust versions
* Wed Oct 30 2024 Michael Vetter <mvetter@suse.com>
- Update to 3.3.6:
  * Prevent timeouts on large differences by not doing any
    refinement on the large sections.
* Thu Oct 24 2024 Michael Vetter <mvetter@suse.com>
- Update to 3.3.5:
  * With this release, many more conflicts are recognized, and changes vs
    non-changed line parts are marked much more clearly.
  * This release introduces a --unchanged-style=experimental
    command line option. Try export RIFF=--unchanged-style=experimental
    and report back!
* Fri Oct 11 2024 Michael Vetter <mvetter@suse.com>
- Update to 3.3.4:
  * Both by clearly highlighting the markers, and by improving how
    we color the conflicting areas themselves.
  * And remember: "git config --global merge.conflictstyle diff3"
    is your friend!
* Mon Oct  7 2024 Michael Vetter <mvetter@suse.com>
- Update to 3.3.3:
  * With this release, we go from plain LCS to the Patience Diff algorithm.
    "Patience" is marketed as producing more human friendly diffs.
  * Additionally, post processing has been tuned to take better decisions on
    which differences should be highlighted and not.
* Mon Sep 30 2024 Michael Vetter <mvetter@suse.com>
- Update to 3.3.2:
  * Tune what gets highlighted and not
* Mon Sep 23 2024 Michael Vetter <mvetter@suse.com>
- Update to 3.3.1:
  * Tune leading whitespace lowlighting
* Mon Sep 23 2024 Michael Vetter <mvetter@suse.com>
- Update to 3.3.0:
  * Don't highlight leading whitespace
* Mon Sep  9 2024 Michael Vetter <mvetter@suse.com>
- Update to 3.2.1:
  * Before this release, file names were rendered in all bold.
    Starting with this release though, the paths are rendered
    in normal intensity, but the actual file names are kept bold.
    The goal of this is to improve readability of the output.
* Tue May 21 2024 Michael Vetter <mvetter@suse.com>
- Update to 3.2.0:
  * Especially for diff3 conflicts, where we now show unchanged
    lines vs base in context color:
    https://stackoverflow.com/questions/27417656/should-diff3-be-default-conflictstyle-on-git
  * With this release, we are also better at detecting conflict
    markers in git diff output.
* Mon May 13 2024 Michael Vetter <mvetter@suse.com>
- Update to 3.1.3:
  * By doing our best, highlighting parse errors in the output,
    and then printing an error message after we're done.
    Before this release, we just panicked on parse errors.
* Mon Mar 18 2024 Michael Vetter <mvetter@suse.com>
- Update to 3.1.0:
  * Aka --ignore-all-space, makes a b c be treated as equal to abc.
* Mon Mar 18 2024 Michael Vetter <mvetter@suse.com>
- Update to 3.0.1:
  * Before this release, we just removed all color from git --oneline
    output. With this release, we now retain the existing color for
    lines we have no special handling for. #62
* Mon Mar  4 2024 Michael Vetter <mvetter@suse.com>
- Update to 3.0.0:
  * Starting from now, here's how to integrate with git:
    git config --global pager.diff riff
    git config --global pager.show riff
    git config --global pager.log riff
    git config --global interactive.diffFilter "riff --color=on"
  * Note that the interactive.diffFilter has changed.
* Thu Feb 15 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.32.0:
  * Don't color output when piping
* Mon Feb 12 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.31.1:
  * Fix a hang with large + / - sections
* Thu Feb  8 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.31.0:
  * If you do git diff when there are conflict markers,
    those conflict markers will now be helpfully highlighted.
    See #56 and #57.
* Mon Feb  5 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.30.1:
  * Fix crash by handling conflict markers corner cases properly
* Thu Feb  1 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.30.0:
  * Option to put command line options in the RIFF environment variable
    and riff will use them primarily
  * --no-adds-only-special flag added
  * Improved --- and +++ headers highlighting
* Wed Jan 31 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.20.1:
  * Fix losing part of the diff
  * Align diff file timestamp
* Tue Jan 30 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.29.0:
  * Improve error handling
  * Improve display
* Thu Jan 25 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.28.0:
  * Conflict markers can be added to files by git merge for example.
* Tue Nov 14 2023 Michael Vetter <mvetter@suse.com>
- Update to 2.27.1:
  * Don't require file names with -b #54.
* Sun Sep 24 2023 Michael Vetter <mvetter@suse.com>
- Update to 2.27.0:
  * Fix crash when you remove a line starting with "--" and passed
    the diff to riff, riff would crash #51
    As a side effect, riff will now be pickier with its input. If
    you modify your diffs manually, beware.
* Sun Sep 17 2023 Michael Vetter <mvetter@suse.com>
- Update to 2.26.0:
  * Add -f flag for specifying a diff file to highlight
  * With this release there are two ways of highlighting a particular
    diff file:
    + riff < file.diff
    + riff --file=file.diff
  * Command line parsing has been updated to use Clap, which will
    make help output look somewhat different. Should also fix some
    options parsing corner cases.
* Mon Sep 11 2023 Michael Vetter <mvetter@suse.com>
- Initial package of riff 2.25.2 for openSUSE
